# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class MediaParticipantRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MediaParticipantRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'wrapup': 'Wrapup',
            'state': 'str',
            'recording': 'bool',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'wrapup_skipped': 'bool'
        }

        self.attribute_map = {
            'wrapup': 'wrapup',
            'state': 'state',
            'recording': 'recording',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'wrapup_skipped': 'wrapupSkipped'
        }

        self._wrapup = None
        self._state = None
        self._recording = False
        self._muted = False
        self._confined = False
        self._held = False
        self._wrapup_skipped = False

    @property
    def wrapup(self):
        """
        Gets the wrapup of this MediaParticipantRequest.
        Wrap-up to assign to this participant.

        :return: The wrapup of this MediaParticipantRequest.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this MediaParticipantRequest.
        Wrap-up to assign to this participant.

        :param wrapup: The wrapup of this MediaParticipantRequest.
        :type: Wrapup
        """
        self._wrapup = wrapup

    @property
    def state(self):
        """
        Gets the state of this MediaParticipantRequest.
        The state to update to set for this participant's communications.  Possible values are: 'connected' and 'disconnected'.

        :return: The state of this MediaParticipantRequest.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this MediaParticipantRequest.
        The state to update to set for this participant's communications.  Possible values are: 'connected' and 'disconnected'.

        :param state: The state of this MediaParticipantRequest.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "CONVERTING", "UPLOADING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this MediaParticipantRequest.
        True to enable recording of this participant, otherwise false to disable recording.

        :return: The recording of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this MediaParticipantRequest.
        True to enable recording of this participant, otherwise false to disable recording.

        :param recording: The recording of this MediaParticipantRequest.
        :type: bool
        """
        self._recording = recording

    @property
    def muted(self):
        """
        Gets the muted of this MediaParticipantRequest.
        True to mute this conversation participant.

        :return: The muted of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this MediaParticipantRequest.
        True to mute this conversation participant.

        :param muted: The muted of this MediaParticipantRequest.
        :type: bool
        """
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this MediaParticipantRequest.
        True to confine this conversation participant.  Should only be used for ad-hoc conferences

        :return: The confined of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this MediaParticipantRequest.
        True to confine this conversation participant.  Should only be used for ad-hoc conferences

        :param confined: The confined of this MediaParticipantRequest.
        :type: bool
        """
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this MediaParticipantRequest.
        True to hold this conversation participant.

        :return: The held of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this MediaParticipantRequest.
        True to hold this conversation participant.

        :param held: The held of this MediaParticipantRequest.
        :type: bool
        """
        self._held = held

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this MediaParticipantRequest.
        True to skip wrap-up for this participant.

        :return: The wrapup_skipped of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this MediaParticipantRequest.
        True to skip wrap-up for this participant.

        :param wrapup_skipped: The wrapup_skipped of this MediaParticipantRequest.
        :type: bool
        """
        self._wrapup_skipped = wrapup_skipped

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

