# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class UserStation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserStation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'associated_user': 'User',
            'associated_date': 'datetime',
            'default_user': 'User'
        }

        self.attribute_map = {
            'id': 'id',
            'associated_user': 'associatedUser',
            'associated_date': 'associatedDate',
            'default_user': 'defaultUser'
        }

        self._id = None
        self._associated_user = None
        self._associated_date = None
        self._default_user = None

    @property
    def id(self):
        """
        Gets the id of this UserStation.
        A globally unique identifier for this station

        :return: The id of this UserStation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserStation.
        A globally unique identifier for this station

        :param id: The id of this UserStation.
        :type: str
        """
        self._id = id

    @property
    def associated_user(self):
        """
        Gets the associated_user of this UserStation.


        :return: The associated_user of this UserStation.
        :rtype: User
        """
        return self._associated_user

    @associated_user.setter
    def associated_user(self, associated_user):
        """
        Sets the associated_user of this UserStation.


        :param associated_user: The associated_user of this UserStation.
        :type: User
        """
        self._associated_user = associated_user

    @property
    def associated_date(self):
        """
        Gets the associated_date of this UserStation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The associated_date of this UserStation.
        :rtype: datetime
        """
        return self._associated_date

    @associated_date.setter
    def associated_date(self, associated_date):
        """
        Sets the associated_date of this UserStation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param associated_date: The associated_date of this UserStation.
        :type: datetime
        """
        self._associated_date = associated_date

    @property
    def default_user(self):
        """
        Gets the default_user of this UserStation.


        :return: The default_user of this UserStation.
        :rtype: User
        """
        return self._default_user

    @default_user.setter
    def default_user(self, default_user):
        """
        Sets the default_user of this UserStation.


        :param default_user: The default_user of this UserStation.
        :type: User
        """
        self._default_user = default_user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

