# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FacetResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'request_name': 'str',
            'request_field_name': 'str',
            'field_type': 'str',
            'request_type': 'str',
            'results': 'list[FacetResultItem]'
        }

        self.attribute_map = {
            'request_name': 'requestName',
            'request_field_name': 'requestFieldName',
            'field_type': 'fieldType',
            'request_type': 'requestType',
            'results': 'results'
        }

        self._request_name = None
        self._request_field_name = None
        self._field_type = None
        self._request_type = None
        self._results = None

    @property
    def request_name(self):
        """
        Gets the request_name of this FacetResult.
        This was the name passed in as part of the facetRequest

        :return: The request_name of this FacetResult.
        :rtype: str
        """
        return self._request_name

    @request_name.setter
    def request_name(self, request_name):
        """
        Sets the request_name of this FacetResult.
        This was the name passed in as part of the facetRequest

        :param request_name: The request_name of this FacetResult.
        :type: str
        """
        self._request_name = request_name

    @property
    def request_field_name(self):
        """
        Gets the request_field_name of this FacetResult.
        The field name that the facet was requested for.

        :return: The request_field_name of this FacetResult.
        :rtype: str
        """
        return self._request_field_name

    @request_field_name.setter
    def request_field_name(self, request_field_name):
        """
        Sets the request_field_name of this FacetResult.
        The field name that the facet was requested for.

        :param request_field_name: The request_field_name of this FacetResult.
        :type: str
        """
        self._request_field_name = request_field_name

    @property
    def field_type(self):
        """
        Gets the field_type of this FacetResult.
        data type of the field being returned (if this is a mixed field this will be unknown)

        :return: The field_type of this FacetResult.
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """
        Sets the field_type of this FacetResult.
        data type of the field being returned (if this is a mixed field this will be unknown)

        :param field_type: The field_type of this FacetResult.
        :type: str
        """
        allowed_values = ["NUMBER", "STRING", "DATE", "BOOLEAN", "LIST", "GROUP"]
        if field_type not in allowed_values:
            raise ValueError(
                "Invalid value for `field_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._field_type = field_type

    @property
    def request_type(self):
        """
        Gets the request_type of this FacetResult.
        the facet request type that was made.

        :return: The request_type of this FacetResult.
        :rtype: str
        """
        return self._request_type

    @request_type.setter
    def request_type(self, request_type):
        """
        Sets the request_type of this FacetResult.
        the facet request type that was made.

        :param request_type: The request_type of this FacetResult.
        :type: str
        """
        allowed_values = ["TERM", "RANGE"]
        if request_type not in allowed_values:
            raise ValueError(
                "Invalid value for `request_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._request_type = request_type

    @property
    def results(self):
        """
        Gets the results of this FacetResult.


        :return: The results of this FacetResult.
        :rtype: list[FacetResultItem]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this FacetResult.


        :param results: The results of this FacetResult.
        :type: list[FacetResultItem]
        """
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

