# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class NumberOrderRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NumberOrderRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'order_tns': 'list[str]',
            'reservation_ids': 'list[str]',
            'order_id': 'str',
            'effective_date': 'datetime',
            'phone_number_type': 'str'
        }

        self.attribute_map = {
            'order_tns': 'orderTns',
            'reservation_ids': 'reservationIds',
            'order_id': 'orderId',
            'effective_date': 'effectiveDate',
            'phone_number_type': 'phoneNumberType'
        }

        self._order_tns = None
        self._reservation_ids = None
        self._order_id = None
        self._effective_date = None
        self._phone_number_type = None

    @property
    def order_tns(self):
        """
        Gets the order_tns of this NumberOrderRequest.


        :return: The order_tns of this NumberOrderRequest.
        :rtype: list[str]
        """
        return self._order_tns

    @order_tns.setter
    def order_tns(self, order_tns):
        """
        Sets the order_tns of this NumberOrderRequest.


        :param order_tns: The order_tns of this NumberOrderRequest.
        :type: list[str]
        """
        self._order_tns = order_tns

    @property
    def reservation_ids(self):
        """
        Gets the reservation_ids of this NumberOrderRequest.


        :return: The reservation_ids of this NumberOrderRequest.
        :rtype: list[str]
        """
        return self._reservation_ids

    @reservation_ids.setter
    def reservation_ids(self, reservation_ids):
        """
        Sets the reservation_ids of this NumberOrderRequest.


        :param reservation_ids: The reservation_ids of this NumberOrderRequest.
        :type: list[str]
        """
        self._reservation_ids = reservation_ids

    @property
    def order_id(self):
        """
        Gets the order_id of this NumberOrderRequest.


        :return: The order_id of this NumberOrderRequest.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """
        Sets the order_id of this NumberOrderRequest.


        :param order_id: The order_id of this NumberOrderRequest.
        :type: str
        """
        self._order_id = order_id

    @property
    def effective_date(self):
        """
        Gets the effective_date of this NumberOrderRequest.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_date of this NumberOrderRequest.
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this NumberOrderRequest.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_date: The effective_date of this NumberOrderRequest.
        :type: datetime
        """
        self._effective_date = effective_date

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this NumberOrderRequest.
        The type of phone number (eg us-domestic, toll-free, etc), to determine which third-party api(s) to use for the order request.

        :return: The phone_number_type of this NumberOrderRequest.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this NumberOrderRequest.
        The type of phone number (eg us-domestic, toll-free, etc), to determine which third-party api(s) to use for the order request.

        :param phone_number_type: The phone_number_type of this NumberOrderRequest.
        :type: str
        """
        allowed_values = ["TOLL_FREE", "CN_DOMESTIC", "US_DOMESTIC"]
        if phone_number_type not in allowed_values:
            raise ValueError(
                "Invalid value for `phone_number_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._phone_number_type = phone_number_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

