# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class OAuthClient(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OAuthClient - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'access_token_validity_seconds': 'int',
            'description': 'str',
            'registered_redirect_uri': 'list[str]',
            'secret': 'str',
            'role_ids': 'list[str]',
            'authorized_grant_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'access_token_validity_seconds': 'accessTokenValiditySeconds',
            'description': 'description',
            'registered_redirect_uri': 'registeredRedirectUri',
            'secret': 'secret',
            'role_ids': 'roleIds',
            'authorized_grant_type': 'authorizedGrantType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._access_token_validity_seconds = None
        self._description = None
        self._registered_redirect_uri = None
        self._secret = None
        self._role_ids = None
        self._authorized_grant_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OAuthClient.
        The globally unique identifier for the object.

        :return: The id of this OAuthClient.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OAuthClient.
        The globally unique identifier for the object.

        :param id: The id of this OAuthClient.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OAuthClient.
        The name of the OAuth client.

        :return: The name of this OAuthClient.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OAuthClient.
        The name of the OAuth client.

        :param name: The name of this OAuthClient.
        :type: str
        """
        self._name = name

    @property
    def access_token_validity_seconds(self):
        """
        Gets the access_token_validity_seconds of this OAuthClient.
        The number of seconds, between 5mins and 48hrs, until tokens created with this client expire. If this field is omitted, a default of 24 hours will be applied.

        :return: The access_token_validity_seconds of this OAuthClient.
        :rtype: int
        """
        return self._access_token_validity_seconds

    @access_token_validity_seconds.setter
    def access_token_validity_seconds(self, access_token_validity_seconds):
        """
        Sets the access_token_validity_seconds of this OAuthClient.
        The number of seconds, between 5mins and 48hrs, until tokens created with this client expire. If this field is omitted, a default of 24 hours will be applied.

        :param access_token_validity_seconds: The access_token_validity_seconds of this OAuthClient.
        :type: int
        """
        self._access_token_validity_seconds = access_token_validity_seconds

    @property
    def description(self):
        """
        Gets the description of this OAuthClient.


        :return: The description of this OAuthClient.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OAuthClient.


        :param description: The description of this OAuthClient.
        :type: str
        """
        self._description = description

    @property
    def registered_redirect_uri(self):
        """
        Gets the registered_redirect_uri of this OAuthClient.
        List of allowed callbacks for this client. For example: https://myap.example.com/auth/callback

        :return: The registered_redirect_uri of this OAuthClient.
        :rtype: list[str]
        """
        return self._registered_redirect_uri

    @registered_redirect_uri.setter
    def registered_redirect_uri(self, registered_redirect_uri):
        """
        Sets the registered_redirect_uri of this OAuthClient.
        List of allowed callbacks for this client. For example: https://myap.example.com/auth/callback

        :param registered_redirect_uri: The registered_redirect_uri of this OAuthClient.
        :type: list[str]
        """
        self._registered_redirect_uri = registered_redirect_uri

    @property
    def secret(self):
        """
        Gets the secret of this OAuthClient.
        System created secret assigned to this client. Secrets are required for code authorization grants.

        :return: The secret of this OAuthClient.
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """
        Sets the secret of this OAuthClient.
        System created secret assigned to this client. Secrets are required for code authorization grants.

        :param secret: The secret of this OAuthClient.
        :type: str
        """
        self._secret = secret

    @property
    def role_ids(self):
        """
        Gets the role_ids of this OAuthClient.
        Roles assigned to this client. Roles only apply to clients using the client_credential grant

        :return: The role_ids of this OAuthClient.
        :rtype: list[str]
        """
        return self._role_ids

    @role_ids.setter
    def role_ids(self, role_ids):
        """
        Sets the role_ids of this OAuthClient.
        Roles assigned to this client. Roles only apply to clients using the client_credential grant

        :param role_ids: The role_ids of this OAuthClient.
        :type: list[str]
        """
        self._role_ids = role_ids

    @property
    def authorized_grant_type(self):
        """
        Gets the authorized_grant_type of this OAuthClient.
        The OAuth Grant/Client type supported by this client.

        :return: The authorized_grant_type of this OAuthClient.
        :rtype: str
        """
        return self._authorized_grant_type

    @authorized_grant_type.setter
    def authorized_grant_type(self, authorized_grant_type):
        """
        Sets the authorized_grant_type of this OAuthClient.
        The OAuth Grant/Client type supported by this client.

        :param authorized_grant_type: The authorized_grant_type of this OAuthClient.
        :type: str
        """
        allowed_values = ["CODE", "TOKEN", "CLIENT-CREDENTIALS"]
        if authorized_grant_type not in allowed_values:
            raise ValueError(
                "Invalid value for `authorized_grant_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._authorized_grant_type = authorized_grant_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OAuthClient.
        The URI for this object

        :return: The self_uri of this OAuthClient.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OAuthClient.
        The URI for this object

        :param self_uri: The self_uri of this OAuthClient.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

