# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SearchCriteria(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SearchCriteria - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'end_value': 'str',
            'values': 'list[str]',
            'start_value': 'str',
            'type': 'str',
            'fields': 'list[str]',
            'value': 'str',
            'operator': 'str',
            'group': 'list[SearchCriteria]'
        }

        self.attribute_map = {
            'end_value': 'endValue',
            'values': 'values',
            'start_value': 'startValue',
            'type': 'type',
            'fields': 'fields',
            'value': 'value',
            'operator': 'operator',
            'group': 'group'
        }

        self._end_value = None
        self._values = None
        self._start_value = None
        self._type = None
        self._fields = None
        self._value = None
        self._operator = None
        self._group = None

    @property
    def end_value(self):
        """
        Gets the end_value of this SearchCriteria.


        :return: The end_value of this SearchCriteria.
        :rtype: str
        """
        return self._end_value

    @end_value.setter
    def end_value(self, end_value):
        """
        Sets the end_value of this SearchCriteria.


        :param end_value: The end_value of this SearchCriteria.
        :type: str
        """
        self._end_value = end_value

    @property
    def values(self):
        """
        Gets the values of this SearchCriteria.


        :return: The values of this SearchCriteria.
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this SearchCriteria.


        :param values: The values of this SearchCriteria.
        :type: list[str]
        """
        self._values = values

    @property
    def start_value(self):
        """
        Gets the start_value of this SearchCriteria.


        :return: The start_value of this SearchCriteria.
        :rtype: str
        """
        return self._start_value

    @start_value.setter
    def start_value(self, start_value):
        """
        Sets the start_value of this SearchCriteria.


        :param start_value: The start_value of this SearchCriteria.
        :type: str
        """
        self._start_value = start_value

    @property
    def type(self):
        """
        Gets the type of this SearchCriteria.


        :return: The type of this SearchCriteria.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SearchCriteria.


        :param type: The type of this SearchCriteria.
        :type: str
        """
        allowed_values = ["EXACT", "CONTAINS", "STARTS_WITH", "REQUIRED_FIELDS", "RANGE", "DATE_RANGE", "LESS_THAN", "LESS_THAN_EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL_TO", "SIMPLE_STRING"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def fields(self):
        """
        Gets the fields of this SearchCriteria.


        :return: The fields of this SearchCriteria.
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this SearchCriteria.


        :param fields: The fields of this SearchCriteria.
        :type: list[str]
        """
        self._fields = fields

    @property
    def value(self):
        """
        Gets the value of this SearchCriteria.


        :return: The value of this SearchCriteria.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SearchCriteria.


        :param value: The value of this SearchCriteria.
        :type: str
        """
        self._value = value

    @property
    def operator(self):
        """
        Gets the operator of this SearchCriteria.


        :return: The operator of this SearchCriteria.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this SearchCriteria.


        :param operator: The operator of this SearchCriteria.
        :type: str
        """
        allowed_values = ["AND", "OR", "NOT"]
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator`, must be one of {0}"
                .format(allowed_values)
            )
        self._operator = operator

    @property
    def group(self):
        """
        Gets the group of this SearchCriteria.


        :return: The group of this SearchCriteria.
        :rtype: list[SearchCriteria]
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this SearchCriteria.


        :param group: The group of this SearchCriteria.
        :type: list[SearchCriteria]
        """
        self._group = group

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

