# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class EdgeGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'managed': 'bool',
            'edge_trunk_base_assignment': 'TrunkBaseAssignment',
            'phone_trunk_base_assignments': 'list[TrunkBaseAssignment]',
            'phone_trunk_bases': 'list[UriReference]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'managed': 'managed',
            'edge_trunk_base_assignment': 'edgeTrunkBaseAssignment',
            'phone_trunk_base_assignments': 'phoneTrunkBaseAssignments',
            'phone_trunk_bases': 'phoneTrunkBases',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._managed = False
        self._edge_trunk_base_assignment = None
        self._phone_trunk_base_assignments = None
        self._phone_trunk_bases = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EdgeGroup.
        The globally unique identifier for the object.

        :return: The id of this EdgeGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EdgeGroup.
        The globally unique identifier for the object.

        :param id: The id of this EdgeGroup.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EdgeGroup.


        :return: The name of this EdgeGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeGroup.


        :param name: The name of this EdgeGroup.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this EdgeGroup.


        :return: The description of this EdgeGroup.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this EdgeGroup.


        :param description: The description of this EdgeGroup.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this EdgeGroup.


        :return: The version of this EdgeGroup.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this EdgeGroup.


        :param version: The version of this EdgeGroup.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this EdgeGroup.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this EdgeGroup.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this EdgeGroup.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this EdgeGroup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this EdgeGroup.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this EdgeGroup.


        :return: The modified_by of this EdgeGroup.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this EdgeGroup.


        :param modified_by: The modified_by of this EdgeGroup.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this EdgeGroup.


        :return: The created_by of this EdgeGroup.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this EdgeGroup.


        :param created_by: The created_by of this EdgeGroup.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this EdgeGroup.


        :return: The state of this EdgeGroup.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this EdgeGroup.


        :param state: The state of this EdgeGroup.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this EdgeGroup.


        :return: The modified_by_app of this EdgeGroup.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this EdgeGroup.


        :param modified_by_app: The modified_by_app of this EdgeGroup.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this EdgeGroup.


        :return: The created_by_app of this EdgeGroup.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this EdgeGroup.


        :param created_by_app: The created_by_app of this EdgeGroup.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def managed(self):
        """
        Gets the managed of this EdgeGroup.
        Is this edge group being managed remotely.

        :return: The managed of this EdgeGroup.
        :rtype: bool
        """
        return self._managed

    @managed.setter
    def managed(self, managed):
        """
        Sets the managed of this EdgeGroup.
        Is this edge group being managed remotely.

        :param managed: The managed of this EdgeGroup.
        :type: bool
        """
        self._managed = managed

    @property
    def edge_trunk_base_assignment(self):
        """
        Gets the edge_trunk_base_assignment of this EdgeGroup.
        A trunk base settings assignment of trunkType \"EDGE\" to use for edge-to-edge communication.

        :return: The edge_trunk_base_assignment of this EdgeGroup.
        :rtype: TrunkBaseAssignment
        """
        return self._edge_trunk_base_assignment

    @edge_trunk_base_assignment.setter
    def edge_trunk_base_assignment(self, edge_trunk_base_assignment):
        """
        Sets the edge_trunk_base_assignment of this EdgeGroup.
        A trunk base settings assignment of trunkType \"EDGE\" to use for edge-to-edge communication.

        :param edge_trunk_base_assignment: The edge_trunk_base_assignment of this EdgeGroup.
        :type: TrunkBaseAssignment
        """
        self._edge_trunk_base_assignment = edge_trunk_base_assignment

    @property
    def phone_trunk_base_assignments(self):
        """
        Gets the phone_trunk_base_assignments of this EdgeGroup.
        Trunk base settings assignments of trunkType \"PHONE\" to inherit to edge logical interfaces for phone communication.

        :return: The phone_trunk_base_assignments of this EdgeGroup.
        :rtype: list[TrunkBaseAssignment]
        """
        return self._phone_trunk_base_assignments

    @phone_trunk_base_assignments.setter
    def phone_trunk_base_assignments(self, phone_trunk_base_assignments):
        """
        Sets the phone_trunk_base_assignments of this EdgeGroup.
        Trunk base settings assignments of trunkType \"PHONE\" to inherit to edge logical interfaces for phone communication.

        :param phone_trunk_base_assignments: The phone_trunk_base_assignments of this EdgeGroup.
        :type: list[TrunkBaseAssignment]
        """
        self._phone_trunk_base_assignments = phone_trunk_base_assignments

    @property
    def phone_trunk_bases(self):
        """
        Gets the phone_trunk_bases of this EdgeGroup.
        Trunk base settings of trunkType \"PHONE\" to inherit to edge logical interface for phone communication.

        :return: The phone_trunk_bases of this EdgeGroup.
        :rtype: list[UriReference]
        """
        return self._phone_trunk_bases

    @phone_trunk_bases.setter
    def phone_trunk_bases(self, phone_trunk_bases):
        """
        Sets the phone_trunk_bases of this EdgeGroup.
        Trunk base settings of trunkType \"PHONE\" to inherit to edge logical interface for phone communication.

        :param phone_trunk_bases: The phone_trunk_bases of this EdgeGroup.
        :type: list[UriReference]
        """
        self._phone_trunk_bases = phone_trunk_bases

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EdgeGroup.
        The URI for this object

        :return: The self_uri of this EdgeGroup.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EdgeGroup.
        The URI for this object

        :param self_uri: The self_uri of this EdgeGroup.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

