# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DiagnosticEmail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DiagnosticEmail - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'subject': 'str',
            'topic': 'str',
            'description': 'str',
            'priority': 'str',
            'type': 'str',
            'data': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'subject': 'subject',
            'topic': 'topic',
            'description': 'description',
            'priority': 'priority',
            'type': 'type',
            'data': 'data'
        }

        self._id = None
        self._subject = None
        self._topic = None
        self._description = None
        self._priority = None
        self._type = None
        self._data = None

    @property
    def id(self):
        """
        Gets the id of this DiagnosticEmail.
        The globally unique identifier for the object.

        :return: The id of this DiagnosticEmail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DiagnosticEmail.
        The globally unique identifier for the object.

        :param id: The id of this DiagnosticEmail.
        :type: str
        """
        self._id = id

    @property
    def subject(self):
        """
        Gets the subject of this DiagnosticEmail.
        Subject of Issue Report

        :return: The subject of this DiagnosticEmail.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this DiagnosticEmail.
        Subject of Issue Report

        :param subject: The subject of this DiagnosticEmail.
        :type: str
        """
        self._subject = subject

    @property
    def topic(self):
        """
        Gets the topic of this DiagnosticEmail.
        Functional Area of Issue

        :return: The topic of this DiagnosticEmail.
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """
        Sets the topic of this DiagnosticEmail.
        Functional Area of Issue

        :param topic: The topic of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["Admin", "Documents", "Chat", "Video Chat", "Login", "Slowness", "Other"]
        if topic not in allowed_values:
            raise ValueError(
                "Invalid value for `topic`, must be one of {0}"
                .format(allowed_values)
            )
        self._topic = topic

    @property
    def description(self):
        """
        Gets the description of this DiagnosticEmail.
        Detailed Description of Issue

        :return: The description of this DiagnosticEmail.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DiagnosticEmail.
        Detailed Description of Issue

        :param description: The description of this DiagnosticEmail.
        :type: str
        """
        self._description = description

    @property
    def priority(self):
        """
        Gets the priority of this DiagnosticEmail.


        :return: The priority of this DiagnosticEmail.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this DiagnosticEmail.


        :param priority: The priority of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if priority not in allowed_values:
            raise ValueError(
                "Invalid value for `priority`, must be one of {0}"
                .format(allowed_values)
            )
        self._priority = priority

    @property
    def type(self):
        """
        Gets the type of this DiagnosticEmail.
        Type of Issue

        :return: The type of this DiagnosticEmail.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DiagnosticEmail.
        Type of Issue

        :param type: The type of this DiagnosticEmail.
        :type: str
        """
        allowed_values = ["Problem", "Question", "Enhancement Request"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def data(self):
        """
        Gets the data of this DiagnosticEmail.
        Json blob of data to be included with this report.

        :return: The data of this DiagnosticEmail.
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this DiagnosticEmail.
        Json blob of data to be included with this report.

        :param data: The data of this DiagnosticEmail.
        :type: object
        """
        self._data = data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

