# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DependencyStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DependencyStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'User',
            'build_id': 'str',
            'date_started': 'datetime',
            'date_completed': 'datetime',
            'status': 'str',
            'failed_objects': 'list[FailedObject]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'build_id': 'buildId',
            'date_started': 'dateStarted',
            'date_completed': 'dateCompleted',
            'status': 'status',
            'failed_objects': 'failedObjects',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._build_id = None
        self._date_started = None
        self._date_completed = None
        self._status = None
        self._failed_objects = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DependencyStatus.
        The globally unique identifier for the object.

        :return: The id of this DependencyStatus.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DependencyStatus.
        The globally unique identifier for the object.

        :param id: The id of this DependencyStatus.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DependencyStatus.


        :return: The name of this DependencyStatus.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DependencyStatus.


        :param name: The name of this DependencyStatus.
        :type: str
        """
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this DependencyStatus.


        :return: The user of this DependencyStatus.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this DependencyStatus.


        :param user: The user of this DependencyStatus.
        :type: User
        """
        self._user = user

    @property
    def build_id(self):
        """
        Gets the build_id of this DependencyStatus.


        :return: The build_id of this DependencyStatus.
        :rtype: str
        """
        return self._build_id

    @build_id.setter
    def build_id(self, build_id):
        """
        Sets the build_id of this DependencyStatus.


        :param build_id: The build_id of this DependencyStatus.
        :type: str
        """
        self._build_id = build_id

    @property
    def date_started(self):
        """
        Gets the date_started of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_started of this DependencyStatus.
        :rtype: datetime
        """
        return self._date_started

    @date_started.setter
    def date_started(self, date_started):
        """
        Sets the date_started of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_started: The date_started of this DependencyStatus.
        :type: datetime
        """
        self._date_started = date_started

    @property
    def date_completed(self):
        """
        Gets the date_completed of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_completed of this DependencyStatus.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_completed: The date_completed of this DependencyStatus.
        :type: datetime
        """
        self._date_completed = date_completed

    @property
    def status(self):
        """
        Gets the status of this DependencyStatus.


        :return: The status of this DependencyStatus.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DependencyStatus.


        :param status: The status of this DependencyStatus.
        :type: str
        """
        allowed_values = ["BUILDINITIALIZING", "BUILDINPROGRESS", "NOTBUILT", "OPERATIONAL", "OPERATIONALNEEDSREBUILD"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def failed_objects(self):
        """
        Gets the failed_objects of this DependencyStatus.


        :return: The failed_objects of this DependencyStatus.
        :rtype: list[FailedObject]
        """
        return self._failed_objects

    @failed_objects.setter
    def failed_objects(self, failed_objects):
        """
        Sets the failed_objects of this DependencyStatus.


        :param failed_objects: The failed_objects of this DependencyStatus.
        :type: list[FailedObject]
        """
        self._failed_objects = failed_objects

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DependencyStatus.
        The URI for this object

        :return: The self_uri of this DependencyStatus.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DependencyStatus.
        The URI for this object

        :param self_uri: The self_uri of this DependencyStatus.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

