# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class OrganizationCreate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrganizationCreate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'admin_username': 'str',
            'admin_password': 'str',
            'domain': 'str',
            'third_party_org_name': 'str',
            'deletable': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'admin_username': 'adminUsername',
            'admin_password': 'adminPassword',
            'domain': 'domain',
            'third_party_org_name': 'thirdPartyOrgName',
            'deletable': 'deletable'
        }

        self._name = None
        self._admin_username = None
        self._admin_password = None
        self._domain = None
        self._third_party_org_name = None
        self._deletable = False

    @property
    def name(self):
        """
        Gets the name of this OrganizationCreate.
        Display Name for Organization

        :return: The name of this OrganizationCreate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrganizationCreate.
        Display Name for Organization

        :param name: The name of this OrganizationCreate.
        :type: str
        """
        self._name = name

    @property
    def admin_username(self):
        """
        Gets the admin_username of this OrganizationCreate.
        Administrator username for this organization

        :return: The admin_username of this OrganizationCreate.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this OrganizationCreate.
        Administrator username for this organization

        :param admin_username: The admin_username of this OrganizationCreate.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def admin_password(self):
        """
        Gets the admin_password of this OrganizationCreate.
        Administrator password for this organization

        :return: The admin_password of this OrganizationCreate.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this OrganizationCreate.
        Administrator password for this organization

        :param admin_password: The admin_password of this OrganizationCreate.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def domain(self):
        """
        Gets the domain of this OrganizationCreate.
        Fully qualified domain name for this organization (Ex. example.com).

        :return: The domain of this OrganizationCreate.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this OrganizationCreate.
        Fully qualified domain name for this organization (Ex. example.com).

        :param domain: The domain of this OrganizationCreate.
        :type: str
        """
        self._domain = domain

    @property
    def third_party_org_name(self):
        """
        Gets the third_party_org_name of this OrganizationCreate.
        Organization Name which does not contain special characters like spaces.

        :return: The third_party_org_name of this OrganizationCreate.
        :rtype: str
        """
        return self._third_party_org_name

    @third_party_org_name.setter
    def third_party_org_name(self, third_party_org_name):
        """
        Sets the third_party_org_name of this OrganizationCreate.
        Organization Name which does not contain special characters like spaces.

        :param third_party_org_name: The third_party_org_name of this OrganizationCreate.
        :type: str
        """
        self._third_party_org_name = third_party_org_name

    @property
    def deletable(self):
        """
        Gets the deletable of this OrganizationCreate.
        Deletable Property for Organization.

        :return: The deletable of this OrganizationCreate.
        :rtype: bool
        """
        return self._deletable

    @deletable.setter
    def deletable(self, deletable):
        """
        Sets the deletable of this OrganizationCreate.
        Deletable Property for Organization.

        :param deletable: The deletable of this OrganizationCreate.
        :type: bool
        """
        self._deletable = deletable

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

